@@ -5,19 +5,21 @@ our @EXPORT = ();
 our @EXPORT_OK = qw/
   sort_port
 /;
-our %EXPORT_TAGS = (
-  all => [qw/
-    sort_port
-  /],
-);
+our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-=head1 App::Netdisco::Util::Web
+=head1 NAME
+
+App::Netdisco::Util::Web
+
+=head1 DESCRIPTION
 
 A set of helper subroutines to support parts of the Netdisco application.
 
 There are no default exports, however the C<:all> tag will export all
 subroutines.
 
+=head1 EXPORT_OK
+
 =head2 sort_port( $a, $b )
 
 Sort port names of various types used by device vendors. Interface is as
@@ -34,7 +36,7 @@ sub sort_port {
 
     my $numbers        = qr{^(\d+)$};
     my $numeric        = qr{^([\d\.]+)$};
-    my $dotted_numeric = qr{^(\d+)\.(\d+)$};
+    my $dotted_numeric = qr{^(\d+)[:.](\d+)$};
     my $letter_number  = qr{^([a-zA-Z]+)(\d+)$};
     my $wordcharword   = qr{^([^:\/.]+)[-\ :\/\.]+([^:\/.0-9]+)(\d+)?$}; #port-channel45
     my $netgear        = qr{^Slot: (\d+) Port: (\d+) }; # "Slot: 0 Port: 15 Gigabit - Level"
@@ -114,4 +116,38 @@ sub sort_port {
     return $val;
 }
 
+=head2 sort_modules( $modules )
+
+Sort devices modules into tree hierarchy based upon position and parent -
+input arg is module list.
+
+=cut
+
+sub sort_modules {
+    my $input = shift;
+    my %modules;
+
+    foreach my $module (@$input) {
+        $modules{$module->index}{module} = $module;
+        if ($module->parent) {
+            # Example
+            # index |              description               |        type         | parent |  class  | pos 
+            #-------+----------------------------------------+---------------------+--------+---------+-----
+            #     1 | Cisco Aironet 1200 Series Access Point | cevChassisAIRAP1210 |      0 | chassis |  -1
+            #     3 | PowerPC405GP Ethernet                  | cevPortFEIP         |      1 | port    |  -1
+            #     2 | 802.11G Radio                          | cevPortUnknown      |      1 | port    |   0
+
+            # Some devices do not implement correctly, so given parent
+            # can have multiple items within the same class at a single pos
+            # value.  However, the database results are sorted by 1) parent
+            # 2) class 3) pos 4) index so we should just be able to push onto
+            # the array and ordering be preserved.
+            push(@{$modules{$module->parent}{children}{$module->class}}, $module->index);
+        } else {
+            push(@{$modules{root}}, $module->index);
+        }
+    }
+    return \%modules;
+}
+
 1;
