@@ -56,7 +56,7 @@ hook 'before' => sub {
 
   # override ports form defaults with cookie settings
 
-  my $cookie = cookie('nd_ports-form');
+  my $cookie = (cookie('nd_ports-form') || '');
   my $cdata = url_params_mixed($cookie);
 
   if ($cdata and ref {} eq ref $cdata and not param('reset')) {
@@ -146,6 +146,7 @@ hook 'before_template' => sub {
   my $self_uri = uri_for(request->path, scalar params);
   $self_uri->query_param_delete('q');
   $self_uri->query_param_delete('f');
+  $self_uri->query_param_delete('prefer');
   $tokens->{self_options} = $self_uri->query_form_hash;
 };
 
