@@ -128,6 +128,10 @@
 
     // on page load, load the content for the active tab
     [% IF params.tab %]
-    $('#[% params.tab %]_form').trigger("submit");
+    [% IF params.tab == 'ipinventory' OR params.tab == 'subnets' %]
+      $('#[% params.tab %]_submit').click();
+    [% ELSE %]
+      $('#[% params.tab %]_form').trigger("submit");
+    [% END %]
     [% END %]
   });
